@@ -81,6 +81,8 @@ class XiaoMusic:
         self.cookie_jar = None
         self.mina_service = None
         self.miio_service = None
+        self.login_acount = None
+        self.login_password = None
         self.polling_event = asyncio.Event()
         self.new_record_event = asyncio.Event()
         self.url_cache = MusicUrlCache()
@@ -241,13 +243,35 @@ class XiaoMusic:
 
     async def init_all_data(self, session):
         self.mi_token_home = os.path.join(self.config.conf_path, ".mi.token")
-        await self.login_miboy(session)
+        is_need_login = await self.need_login()
+        if is_need_login:
+            self.log.info("try login")
+            await self.login_miboy(session)
+        else:
+            self.log.info("already logined")
         await self.try_update_device_id()
         cookie_jar = self.get_cookie()
         if cookie_jar:
             session.cookie_jar.update_cookies(cookie_jar)
         self.cookie_jar = session.cookie_jar
 
+    async def need_login(self):
+        if self.mina_service is None:
+            return True
+        if self.mina_service is None:
+            return True
+        if self.login_acount != self.config.account:
+            return True
+        if self.login_password != self.config.password:
+            return True
+
+        try:
+            await self.mina_service.device_list()
+        except Exception as e:
+            self.log.warning(f"可能登录失败. {e}")
+            return True
+        return False
+
     async def login_miboy(self, session):
         try:
             account = MiAccount(
@@ -260,7 +284,12 @@ class XiaoMusic:
             await account.login("micoapi")
             self.mina_service = MiNAService(account)
             self.miio_service = MiIOService(account)
+            self.login_acount = self.config.account
+            self.login_password = self.config.password
+            self.log.info(f"登录完成. {self.login_acount}")
         except Exception as e:
+            self.mina_service = None
+            self.miio_service = None
             self.log.warning(f"可能登录失败. {e}")
 
     async def try_update_device_id(self):
@@ -382,31 +411,20 @@ class XiaoMusic:
     async def get_latest_ask_by_mina(self, device_id):
         try:
             did = self.get_did(device_id)
-            response = await self.mina_service.ubus_request(
-                device_id, "nlp_result_get", "mibrain", {}
-            )
+            messages = await self.mina_service.get_latest_ask(device_id)
             self.log.debug(
-                f"get_latest_ask_by_mina device_id:{device_id} did:{did} response:{response}"
+                f"get_latest_ask_by_mina device_id:{device_id} did:{did} messages:{messages}"
             )
-            if d := response.get("data", {}).get("info", {}):
-                result = json.loads(d).get("result", [{}])
-                if result and len(result) > 0 and result[0].get("nlp"):
-                    answers = (
-                        json.loads(result[0]["nlp"])
-                        .get("response", {})
-                        .get("answer", [{}])
-                    )
-                    if answers:
-                        query = answers[0].get("intention", {}).get("query", "").strip()
-                        timestamp = result[0]["timestamp"] * 1000
-                        answer = answers[0].get("content", {}).get("to_speak")
-                        last_record = {
-                            "time": timestamp,
-                            "did": did,
-                            "query": query,
-                            "answer": answer,
-                        }
-                        self._check_last_query(last_record)
+            for message in messages:
+                query = message.response.answer[0].question
+                answer = message.response.answer[0].content
+                last_record = {
+                    "time": message.timestamp_ms,
+                    "did": did,
+                    "query": query,
+                    "answer": answer,
+                }
+                self._check_last_query(last_record)
         except Exception as e:
             self.log.warning(f"get_latest_ask_by_mina {e}")
         return
@@ -430,7 +448,7 @@ class XiaoMusic:
         did = last_record["did"]
         timestamp = last_record.get("time")
         query = last_record.get("query", "").strip()
-        self.log.debug(f"获取到最后一条对话记录：{query} {timestamp}")
+        self.log.debug(f"{did} 获取到最后一条对话记录：{query} {timestamp}")
 
         if timestamp > self.last_timestamp[did]:
             self.last_timestamp[did] = timestamp
@@ -1125,7 +1143,7 @@ class XiaoMusic:
         name = arg1
         if len(name) == 0:
             name = self.playingmusic(did)
-        self.del_music(name)
+        await self.del_music(name)
 
     async def del_music(self, name):
         filename = self.get_filename(name)
@@ -1540,6 +1558,8 @@ class XiaoMusic:
             device_list = await self.mina_service.device_list()
         except Exception as e:
             self.log.warning(f"Execption {e}")
+            # 重新初始化
+            await self.xiaomusic.reinit()
         return device_list
 
     async def debug_play_by_music_url(self, arg1=None):
